===============
Script Examples
===============

Two scripts are provided as examples. The first was used to reorient the entire RUM-RHUM project. Here it is setup to work on an unique station with the toy data provided with the obsea package. The second was used to localize the same station.

.. toctree::
   :maxdepth: 1

   orientation
   localization

